==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'Em espera',
	'articles_meme_auteur' => 'Todos os artigos deste autor',
	'articles_off' => 'Bloqueados',
	'articles_publie' => 'Publicados',
	'articles_refuse' => 'Eliminados',
	'articles_tous' => 'Todos',
	'aucun_article_syndic' => 'Sem artigos vinculados',
	'avis_echec_syndication_01' => 'A ligação falhou: o backend indicado é indecifrável ou não propõe nenhum artigo. ',
	'avis_echec_syndication_02' => 'A ligação falhou: impossível aceder ao  backend deste sítio.',
	'avis_site_introuvable' => 'Sítio não encontrado',
	'avis_site_syndique_probleme' => 'Atenção: a vinculação deste sítio teve um problema. Por isso, o sistema está temporariamente interrompido. Verifique o endereço do ficheiro de ligação deste sítio (<b>@url_syndic@</b>), e tente uma nova recuperação das informações. ',
	'avis_sites_probleme_syndication' => 'Estes sítios tiveram um problema de vinculação',
	'avis_sites_syndiques_probleme' => 'Estes sítios vinculados provocaram um problema  ',

	// B
	'bouton_exporter' => 'Exportar',
	'bouton_importer' => 'Importar',
	'bouton_radio_modere_posteriori' => 'moderado após a publicação',
	'bouton_radio_modere_priori' => 'moderado antes da publicação',
	'bouton_radio_non_syndication' => 'Não há vinculação',
	'bouton_radio_syndication' => 'Vinculação',

	// C
	'confirmer_purger_syndication' => 'Tem a certeza de que pretende eliminar todos os artigos vinculados deste sítio web ?',

	// E
	'entree_adresse_fichier_syndication' => 'Endereço do ficheiro  « backend » para a vinculação :',
	'entree_adresse_site' => '<b>Endereço do sítio</b> [Obrigatório]',
	'entree_description_site' => 'Descrição do sítio',
	'erreur_fichier_format_inconnu' => 'O formato do ficheiro @fichier@ não é suportado.',
	'erreur_fichier_incorrect' => 'Impossível ler o ficheiro.',

	// F
	'form_prop_nom_site' => 'Nome do sítio',

	// I
	'icone_article_syndic' => 'Artigo vinculado',
	'icone_articles_syndic' => 'Artigos vinculados',
	'icone_controler_syndication' => 'Publicação dos artigos vinculados',
	'icone_modifier_site' => 'Modificar este sítio',
	'icone_referencer_nouveau_site' => 'Referenciar um novo sítio',
	'icone_site_reference' => 'Sítios Web referenciados',
	'icone_supprimer_article' => 'Eliminar este artigo',
	'icone_supprimer_articles' => 'Eliminar estes artigos',
	'icone_valider_article' => 'Validar este artigo',
	'icone_valider_articles' => 'Validar estes artigos',
	'icone_voir_sites_references' => 'Ver os sítios referenciados',
	'info_1_site_importe' => '1 sítio foi importado',
	'info_a_valider' => '[a validar]',
	'info_aucun_site_importe' => 'Nenhum sítio web foi importado',
	'info_bloquer' => 'bloquear',
	'info_bloquer_lien' => 'bloquear esta ligação',
	'info_derniere_syndication' => 'A última vinculação deste sítio foi efectuada a',
	'info_liens_syndiques_1' => 'laços vinculados',
	'info_liens_syndiques_2' => 'estão à espera de validação',
	'info_nb_sites_importes' => '@nb@ sítios web foram importados',
	'info_nom_site_2' => '<b>Nome do sítio</b> [Obrigatório]',
	'info_panne_site_syndique' => 'Sítio vinculado não disponível',
	'info_probleme_grave' => 'erro em',
	'info_question_proposer_site' => 'Quem pode propor sítios referenciados ?',
	'info_retablir_lien' => 'restabelecer esta ligação',
	'info_site_attente' => 'Sítio Web à espera de validação',
	'info_site_propose' => 'Sítio proposto a :',
	'info_site_reference' => 'Sítio referenciado online',
	'info_site_refuse' => 'Sítio Web recusado',
	'info_site_syndique' => 'Este sítio está vinculado....',
	'info_site_valider' => 'Sítios a validar',
	'info_sites_referencer' => 'Referenciar este sítio',
	'info_sites_refuses' => 'Os sítios recusados ',
	'info_statut_site_1' => 'Este sítio é :',
	'info_statut_site_2' => 'Publicado',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'No caixote do lixo',
	'info_syndication' => 'vinculação:',
	'info_syndication_articles' => 'artigo(s)',
	'item_bloquer_liens_syndiques' => 'Bloquear as ligações vinculadas para validação',
	'item_gerer_annuaire_site_web' => 'Gerir um directório de sítios Web',
	'item_non_bloquer_liens_syndiques' => 'Não bloquear as ligações resultantes da vinculação',
	'item_non_gerer_annuaire_site_web' => 'Desactivar o directório de sítios Web',
	'item_non_utiliser_syndication' => 'Não utilizar a vinculação automática',
	'item_utiliser_syndication' => 'Utilizar a vinculação automática',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exportar as palavras-chave como tags',
	'label_exporter_id_parent' => 'Exportar os sítios web da rubrica',
	'label_exporter_publie_seulement_1' => 'Exportar unicamente os sítios web publicados',
	'label_fichier_import' => 'Ficheiro HTML',
	'label_importer_les_tags_1' => 'Importar tags como palavras-chave',
	'label_importer_statut_publie_1' => 'Publicar automaticamente os sítios web',
	'lien_mise_a_jour_syndication' => 'Actualizar agora',
	'lien_nouvelle_recuperation' => 'Tentar uma nova recuperação dos dados',
	'lien_purger_syndication' => 'Eliminar todos os artigos vinculados',

	// N
	'nombre_articles_syndic' => '@nb@ artigos vinculados',

	// S
	'statut_off' => 'Eliminado',
	'statut_prop' => 'Em espera',
	'statut_publie' => 'Publicado',
	'syndic_choix_moderation' => 'Que fazer com as novas ligações provenientes deste sítio ?',
	'syndic_choix_oublier' => 'Que fazer com as ligações que já não aparecem no ficheiro de vinculação?',
	'syndic_choix_resume' => 'Certos sítios incluem o texto completo dos artigos. Quando este se encontra disponível, pretende vincular:',
	'syndic_lien_obsolete' => 'ligação desactualizada',
	'syndic_option_miroir' => 'bloquear automaticamente',
	'syndic_option_oubli' => 'eliminar (após @mês@ mês)',
	'syndic_option_resume_non' => 'o conteúdo completo dos artigos (em formato HTML)',
	'syndic_option_resume_oui' => 'apenas um resumo (em formato de texto)',
	'syndic_options' => 'Opções de vinculação :',

	// T
	'texte_expliquer_export_bookmarks' => 'Pode exportar uma lista de sítios web com o formato de marcador HTML, para que possa importá-la para o seu navegador ou para um serviço online.',
	'texte_expliquer_import_bookmarks' => 'Pode importar uma lista de sítios web a partir do formato Marcador HTML, do seu navegador ou de outro serviço online de gestão de marcadores.',
	'texte_liens_sites_syndiques' => 'As ligações de sítios vinculados podem
 ser bloqueados antes da publicação. A seguinte definição a configuração por defeito dos
 sítios vinculados depois da sua criação. É possível, de qualquer modo, desbloquear cada ligação individualmente, ou escolher, sítio por sítio, bloquear as ligações futuras deste ou daquele sítio.',
	'texte_messages_publics' => 'Mensagens públicas neste artigo :',
	'texte_non_fonction_referencement' => 'Pode preferir não utilizar esta função automática, e indicar manualmente os elementos relativos a este sítio...',
	'texte_referencement_automatique' => '<b>Referenciamento automatizado de um sítio</b><br />Pode referenciar rapidamente um sítio Web indicando a seguir o endereço URL desejado, ou o endereço do seu ficheiro de vinculação. SPIP vai recuperar automaticamente as informações relativas a esse sítio (título, descrição...).',
	'texte_referencement_automatique_verifier' => 'Por favor verifique a informação fornecida por <tt>@url@</tt> antes de guardar.',
	'texte_syndication' => 'É possível recuperar automaticamente, quando um sítio Web o permitir, 
 a lista das suas novidades. Para tal, deve activar a vinculação. 
  <blockquote><i>Alguns serviços de hospedagem desactivam esta funcionalidade ; 
 neste caso, não poderá utilizar a vinculação de conteúdo
a partir do seu sítio.</i></blockquote>',
	'titre_articles_syndiques' => 'Artigos vinculados tirados deste sítio',
	'titre_dernier_article_syndique' => 'Últimos artigos vinculados',
	'titre_exporter_bookmarks' => 'Exportar os Marcadores',
	'titre_importer_bookmarks' => 'Importar os Marcadores',
	'titre_importer_exporter_bookmarks' => 'Importar e exportar os Marcadores',
	'titre_page_sites_tous' => 'Os sítios referenciados',
	'titre_referencement_sites' => 'Referenciação de sítios e vinculação',
	'titre_site_numero' => 'SÍTIO NÚMERO :',
	'titre_sites_proposes' => 'Os sítios propostos',
	'titre_sites_references_rubrique' => 'Os sítios referenciados nesta rubrica',
	'titre_sites_syndiques' => 'Os sítios vinculados',
	'titre_sites_tous' => 'Os sítios referenciados',
	'titre_syndication' => 'Vinculação de sítios',
	'tout_voir' => 'Ver todos os artigos vinculados',

	// U
	'un_article_syndic' => '1 artigo vinculado'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'Em espera',
	'articles_meme_auteur' => 'Todos os artigos deste autor',
	'articles_off' => 'Bloqueados',
	'articles_publie' => 'Publicados',
	'articles_refuse' => 'Eliminados',
	'articles_tous' => 'Todos',
	'aucun_article_syndic' => 'Sem artigos vinculados',
	'avis_echec_syndication_01' => 'A ligação falhou: o backend indicado é indecifrável ou não propõe nenhum artigo. ',
	'avis_echec_syndication_02' => 'A ligação falhou: impossível aceder ao  backend deste sítio.',
	'avis_site_introuvable' => 'Sítio não encontrado',
	'avis_site_syndique_probleme' => 'Atenção: a vinculação deste sítio teve um problema. Por isso, o sistema está temporariamente interrompido. Verifique o endereço do ficheiro de ligação deste sítio (<b>@url_syndic@</b>), e tente uma nova recuperação das informações. ',
	'avis_sites_probleme_syndication' => 'Estes sítios tiveram um problema de vinculação',
	'avis_sites_syndiques_probleme' => 'Estes sítios vinculados provocaram um problema  ',

	// B
	'bouton_exporter' => 'Exportar',
	'bouton_importer' => 'Importar',
	'bouton_radio_modere_posteriori' => 'moderado após a publicação',
	'bouton_radio_modere_priori' => 'moderado antes da publicação',
	'bouton_radio_non_syndication' => 'Não há vinculação',
	'bouton_radio_syndication' => 'Vinculação',

	// C
	'confirmer_purger_syndication' => 'Tem a certeza de que pretende eliminar todos os artigos vinculados deste sítio web ?',

	// E
	'entree_adresse_fichier_syndication' => 'Endereço do ficheiro  « backend » para a vinculação :',
	'entree_adresse_site' => '<b>Endereço do sítio</b> [Obrigatório]',
	'entree_description_site' => 'Descrição do sítio',
	'erreur_fichier_format_inconnu' => 'O formato do ficheiro @fichier@ não é suportado.',
	'erreur_fichier_incorrect' => 'Impossível ler o ficheiro.',

	// F
	'form_prop_nom_site' => 'Nome do sítio',

	// I
	'icone_article_syndic' => 'Artigo vinculado',
	'icone_articles_syndic' => 'Artigos vinculados',
	'icone_controler_syndication' => 'Publicação dos artigos vinculados',
	'icone_modifier_site' => 'Modificar este sítio',
	'icone_referencer_nouveau_site' => 'Referenciar um novo sítio',
	'icone_site_reference' => 'Sítios Web referenciados',
	'icone_supprimer_article' => 'Eliminar este artigo',
	'icone_supprimer_articles' => 'Eliminar estes artigos',
	'icone_valider_article' => 'Validar este artigo',
	'icone_valider_articles' => 'Validar estes artigos',
	'icone_voir_sites_references' => 'Ver os sítios referenciados',
	'info_1_article_syndique' => '1 artigo redifundido',
	'info_1_site' => '1 sítio',
	'info_1_site_importe' => '1 sítio foi importado',
	'info_a_valider' => '[a validar]',
	'info_aucun_article_syndique' => 'Sem artigos redifundidos',
	'info_aucun_site' => 'Nenhum sítio ',
	'info_aucun_site_importe' => 'Nenhum sítio web foi importado',
	'info_bloquer' => 'bloquear',
	'info_bloquer_lien' => 'bloquear esta ligação',
	'info_derniere_syndication' => 'A última vinculação deste sítio foi efectuada a',
	'info_liens_syndiques_1' => 'laços vinculados',
	'info_liens_syndiques_2' => 'estão à espera de validação',
	'info_nb_articles_syndiques' => '@nb@ artigos redifundidos',
	'info_nb_sites' => '@nb@ sítios',
	'info_nb_sites_importes' => '@nb@ sítios web foram importados',
	'info_nom_site_2' => '<b>Nome do sítio</b> [Obrigatório]',
	'info_panne_site_syndique' => 'Sítio vinculado não disponível',
	'info_probleme_grave' => 'erro em',
	'info_question_proposer_site' => 'Quem pode propor sítios referenciados ?',
	'info_retablir_lien' => 'restabelecer esta ligação',
	'info_site_attente' => 'Sítio Web à espera de validação',
	'info_site_propose' => 'Sítio proposto a :',
	'info_site_reference' => 'Sítio referenciado online',
	'info_site_refuse' => 'Sítio Web recusado',
	'info_site_syndique' => 'Este sítio está vinculado....',
	'info_site_valider' => 'Sítios a validar',
	'info_sites_referencer' => 'Referenciar este sítio',
	'info_sites_refuses' => 'Os sítios recusados ',
	'info_statut_site_1' => 'Este sítio é :',
	'info_statut_site_2' => 'Publicado',
	'info_statut_site_3' => 'Proposto',
	'info_statut_site_4' => 'No caixote do lixo',
	'info_syndication' => 'vinculação:',
	'info_syndication_articles' => 'artigo(s)',
	'item_bloquer_liens_syndiques' => 'Bloquear as ligações vinculadas para validação',
	'item_gerer_annuaire_site_web' => 'Gerir um directório de sítios Web',
	'item_non_bloquer_liens_syndiques' => 'Não bloquear as ligações resultantes da vinculação',
	'item_non_gerer_annuaire_site_web' => 'Desactivar o directório de sítios Web',
	'item_non_utiliser_syndication' => 'Não utilizar a vinculação automática',
	'item_utiliser_syndication' => 'Utilizar a vinculação automática',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exportar as palavras-chave como tags',
	'label_exporter_id_parent' => 'Exportar os sítios web da rubrica',
	'label_exporter_publie_seulement_1' => 'Exportar unicamente os sítios web publicados',
	'label_fichier_import' => 'Ficheiro HTML',
	'label_importer_les_tags_1' => 'Importar tags como palavras-chave',
	'label_importer_statut_publie_1' => 'Publicar automaticamente os sítios web',
	'lien_mise_a_jour_syndication' => 'Actualizar agora',
	'lien_nouvelle_recuperation' => 'Tentar uma nova recuperação dos dados',
	'lien_purger_syndication' => 'Eliminar todos os artigos vinculados',

	// N
	'nombre_articles_syndic' => '@nb@ artigos vinculados',

	// S
	'statut_off' => 'Eliminado',
	'statut_prop' => 'Em espera',
	'statut_publie' => 'Publicado',
	'syndic_choix_moderation' => 'Que fazer com as novas ligações provenientes deste sítio ?',
	'syndic_choix_oublier' => 'Que fazer com as ligações que já não aparecem no ficheiro de vinculação?',
	'syndic_choix_resume' => 'Certos sítios incluem o texto completo dos artigos. Quando este se encontra disponível, pretende vincular:',
	'syndic_lien_obsolete' => 'ligação desactualizada',
	'syndic_option_miroir' => 'bloquear automaticamente',
	'syndic_option_oubli' => 'eliminar (após @mês@ mês)',
	'syndic_option_resume_non' => 'o conteúdo completo dos artigos (em formato HTML)',
	'syndic_option_resume_oui' => 'apenas um resumo (em formato de texto)',
	'syndic_options' => 'Opções de vinculação :',

	// T
	'texte_expliquer_export_bookmarks' => 'Pode exportar uma lista de sítios web com o formato de marcador HTML, para que possa importá-la para o seu navegador ou para um serviço online.',
	'texte_expliquer_import_bookmarks' => 'Pode importar uma lista de sítios web a partir do formato Marcador HTML, do seu navegador ou de outro serviço online de gestão de marcadores.',
	'texte_liens_sites_syndiques' => 'As ligações de sítios vinculados podem
 ser bloqueados antes da publicação. A seguinte definição a configuração por defeito dos
 sítios vinculados depois da sua criação. É possível, de qualquer modo, desbloquear cada ligação individualmente, ou escolher, sítio por sítio, bloquear as ligações futuras deste ou daquele sítio.',
	'texte_messages_publics' => 'Mensagens públicas neste artigo :',
	'texte_non_fonction_referencement' => 'Pode preferir não utilizar esta função automática, e indicar manualmente os elementos relativos a este sítio...',
	'texte_referencement_automatique' => '<b>Referenciamento automatizado de um sítio</b><br />Pode referenciar rapidamente um sítio Web indicando a seguir o endereço URL desejado, ou o endereço do seu ficheiro de vinculação. SPIP vai recuperar automaticamente as informações relativas a esse sítio (título, descrição...).',
	'texte_referencement_automatique_verifier' => 'Por favor verifique a informação fornecida por <tt>@url@</tt> antes de guardar.',
	'texte_syndication' => 'É possível recuperar automaticamente, quando um sítio Web o permitir, 
 a lista das suas novidades. Para tal, deve activar a vinculação. 
  <blockquote><i>Alguns serviços de hospedagem desactivam esta funcionalidade ; 
 neste caso, não poderá utilizar a vinculação de conteúdo
a partir do seu sítio.</i></blockquote>',
	'titre_articles_syndiques' => 'Artigos vinculados tirados deste sítio',
	'titre_dernier_article_syndique' => 'Últimos artigos vinculados',
	'titre_exporter_bookmarks' => 'Exportar os Marcadores',
	'titre_importer_bookmarks' => 'Importar os Marcadores',
	'titre_importer_exporter_bookmarks' => 'Importar e exportar os Marcadores',
	'titre_page_sites_tous' => 'Os sítios referenciados',
	'titre_referencement_sites' => 'Referenciação de sítios e vinculação',
	'titre_site_numero' => 'SÍTIO NÚMERO :',
	'titre_sites_proposes' => 'Os sítios propostos',
	'titre_sites_references_rubrique' => 'Os sítios referenciados nesta rubrica',
	'titre_sites_syndiques' => 'Os sítios vinculados',
	'titre_sites_tous' => 'Os sítios referenciados',
	'titre_syndication' => 'Vinculação de sítios',
	'tout_voir' => 'Ver todos os artigos vinculados',

	// U
	'un_article_syndic' => '1 artigo vinculado'
);

?>
